{inputs, pkgs, ...}: 
{
  programs.kitty.enable = true;

  wayland.windowManager.hyprland = {
    enable = true;
    systemd.enable = true;
    settings = {
      "$mod" = "SUPER";
      bind =
        [
          "$mod, F, exec, firefox"
          "$mod, return, exec, walker"
          "$mod_SHIFT, return, exec, kitty"
          "$mod, s, exec, code"
        ];
      general = {
        gaps_in = 5;
        gaps_out = 5;
        border_size = 1;
      };
      
      misc = {
        disable_hyprland_logo = true;
      };

      input = {
        kb_layout = "de";
      };
    
      decoration = {
        rounding = 5;
      };
      # plugin.virtual-desktops = {}
    };

    plugins = [
      # Touch gestures: https://github.com/horriblename/hyprgrass
      # inputs.hyprgrass.packages.${pkgs.system}.default
      # Virtual desktops: https://github.com/levnikmyskin/hyprland-virtual-desktops
      # inputs.hyprland-virtual-desktops.packages.${pkgs.system}.virtual-desktops
    ];
  };

  imports = [ inputs.hyprpanel.homeManagerModules.hyprpanel ];
  # the overlay makes this available as a home manager module
  programs.hyprpanel = {
    enable = true;
    hyprland.enable = true;
    overwrite.enable = true;
    overlay.enable = true;

    settings = {
      bar = {
        clock.format = "%H:%M";
        clock.showIcon = false;
        launcher.icon = "🚀";
      };
    };
    
    
    
    # Add custom widgets + styling
  };


  programs.walker = {
    enable = true;
    runAsService = true;

    # All options from the config.json can be used here.
    config = {
      search.placeholder = "Search";
      ui.fullscreen = true;
      list = {
        height = 200;
      };
      websearch.prefix = "?";
      switcher.prefix = "/";
    };

    # If this is not set the default styling is used.
    # style = ''
    #   * {
    #     color: #dcd7ba;
    #   }
    # '';
  };


  programs.hyprlock = {
    enable = true;
    settings = {
      general = {
        grace = 5;
        no_fade_in = false;
        disable_loading_bar = false;
      };
    };
  # Style the lock screen
  };

  services.network-manager-applet = {
    enable = true;
  };

}
